@@ -501,7 +501,7 @@ static int getlibraries(textline **plines)
     if (i == elffhdr.e_phnum)
 	return 0;
 
-    count = proghdr[i].p_filesz / sizeof *dyns;
+    count = elfrw_count_Dyns(proghdr[i].p_filesz);
     if (!(dyns = malloc(count * sizeof *dyns)))
 	nomem();
     if (fseek(thefile, proghdr[i].p_offset, SEEK_SET))
